@@ -25,7 +25,7 @@ A module to transform perl variables into R command lines to define simple objs.
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -409,6 +409,22 @@ sub r_var {
 }
 
 
+=head1 ACKNOWLEDGEMENTS
+
+Lukas Mueller
+Robert Buels
+Naama Menda
+Jonathan "Duke" Leto
+
+=head1 COPYRIGHT AND LICENCE
+
+Copyright 2011 Boyce Thompson Institute for Plant Research
+Copyright 2011 Sol Genomics Network (solgenomics.net)
+
+This program is free software; you can redistribute it and/or 
+modify it under the same terms as Perl itself.
+
+=cut
 
 
 ####
